@@ -1,5 +1,5 @@
 #
-# Copyright 2016, Martin Owens <doctormo@gmail.com>
+# Copyright 2017, Martin Owens <doctormo@gmail.com>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -91,11 +91,20 @@ import tempfile
 import subprocess as sp
 
 from time import sleep
-from collections import OrderedDict
 from datetime import time, date, datetime, timedelta
 
+try:
+    from collections import OrderedDict
+except ImportError:
+    # python 2.6 and below causes this error
+    try:
+        from ordereddict import OrderedDict
+    except ImportError:
+        raise ImportError("OrderedDict is required for python-crontab, you can"
+                " install ordereddict 1.1 from pypi for python2.6")
+
 __pkgname__ = 'python-crontab'
-__version__ = '2.1.1'
+__version__ = '2.1.2'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^#\n]*)(\s+#\s*([^\n]*)|$)')
@@ -321,7 +330,7 @@ class CronTab(object):
             if ret is not None:
                 yield ret
 
-    def run_scheduler(self, timeout=0, **kwargs):
+    def run_scheduler(self, timeout=-1, **kwargs):
         """Run the CronTab as an internal scheduler (generator)"""
         count = 0
         self.run_pending()
@@ -356,19 +365,19 @@ class CronTab(object):
 
     def find_command(self, command):
         """Return an iter of jobs matching any part of the command."""
-        for job in self.crons:
+        for job in list(self.crons):
             if command in job.command:
                 yield job
 
     def find_comment(self, comment):
         """Return an iter of jobs that match the comment field exactly."""
-        for job in self.crons:
+        for job in list(self.crons):
             if job.comment == comment:
                 yield job
 
     def find_time(self, *args):
         """Return an iter of jobs that match this time pattern"""
-        for job in self.crons:
+        for job in list(self.crons):
             if job.slices == CronSlices(*args):
                 yield job
 
@@ -1145,6 +1154,9 @@ class CronRange(object):
                 else:
                     self.dangling = 0
                 self.vto = self.slice.parse_value(vto, sunday=6)
+            if self.vto < self.vfrom:
+                logging.warning("Cron range is backwards '%d-%d'" % \
+                        (self.vfrom, self.vto))
         elif value == '*':
             self.all()
         else:
